import { ax as QueryEventGuestsRequest$1, aD as QueryEventGuestsResponse$1 } from './events-guests-v1-guest-guests.universal-CBYtnjLy.mjs';

interface EventGuest {
    /**
     * Guest ID.
     * @format GUID
     */
    id?: string | null;
    /**
     * Event ID.
     * @format GUID
     */
    eventId?: string | null;
    /**
     * RSVP ID. <br/> <br/> **Note:** Only applicable when `guestType` is `"RSVP"`.
     * @format GUID
     */
    rsvpId?: string | null;
    /**
     * Order number. <br/> <br/> **Note:** Only applicable when `guestType` is `"BUYER"` or `"TICKET_HOLDER"`.
     * @maxLength 36
     */
    orderNumber?: string | null;
    /**
     * Ticket number. <br/> <br/> **Note:** Only applicable when `guestType` is `"TICKET_HOLDER"`.
     * @maxLength 36
     */
    ticketNumber?: string | null;
    /**
     * List of names, numbers, and definition IDs for each ticket.
     * @maxSize 50
     */
    tickets?: TicketDetails[];
    /**
     * Guest's contact ID. See the Contacts API for more details.
     * @format GUID
     */
    contactId?: string | null;
    /** Guest details. <br/> <br/> Returned only when the `guestDetails` fieldset is sent in the request. */
    guestDetails?: GuestDetails;
    /**
     * Attendance status. The attendance status updates based on status values in an RSVP object (for RSVP events) or in an Order object (for ticketed events).
     * For more information, see Guest Attendance Status Mapping ([SDK](https://dev.wix.com/docs/sdk/backend-modules/events/guests/guest-attendance-status-mapping) | [REST](https://dev.wix.com/docs/rest/business-solutions/events/event-guests/guest-attendance-status-mapping)). <br/> <br/> **Note:** For `guestType` of `"BUYER"` or `"TICKET_HOLDER"` the `"IN_WAITLIST"` value is not applicable.
     */
    attendanceStatus?: AttendanceStatusWithLiterals;
    /**
     * Secondary language code in [ISO 639-1](https://en.wikipedia.org/wiki/List_of_ISO_639-1_codes) format. Used when the event ticket should be translated into another language.
     * @format LANGUAGE
     */
    secondaryLanguageCode?: string | null;
    /** Date and time the guest was created in `yyyy-mm-ddThh:mm:sssZ` format. */
    createdDate?: Date | null;
    /** Date and time the guest was updated in `yyyy-mm-ddThh:mm:sssZ` format. */
    updatedDate?: Date | null;
    /** Date and time of guest's latest attendance status update. */
    attendanceStatusUpdatedDate?: Date | null;
    /**
     * Site member ID.
     * @format GUID
     */
    memberId?: string | null;
    /** Guest type. */
    guestType?: GuestTypeWithLiterals;
    /**
     * Locale in [IETF BCP 47](https://en.wikipedia.org/wiki/IETF_language_tag) format. Used when the event date and time on a ticket should be formatted into another locale.
     * @format LANGUAGE_TAG
     */
    locale?: string | null;
    /**
     * Number of total guests in an event (registered guests + additional ones).
     * @readonly
     */
    totalGuests?: number | null;
    /**
     * Revision number, which increments by 1 each time the guest is updated.
     * @readonly
     */
    revision?: string | null;
}
interface TicketDetails {
    /**
     * Ticket number.
     * @maxLength 36
     */
    number?: string;
    /**
     * Ticket definition ID.
     * @format GUID
     */
    definitionId?: string | null;
    /**
     * Ticket name.
     * @minLength 1
     * @maxLength 30
     */
    name?: string | null;
}
interface OnlineConferencingLogin {
    /**
     * Link URL to the online conference.
     * @format WEB_URL
     * @readonly
     */
    link?: string;
    /**
     * Password for the online conference.
     * @readonly
     */
    password?: string | null;
}
interface GuestDetails {
    /**
     * Email.
     * @format EMAIL
     */
    email?: string | null;
    /**
     * First name.
     * @maxLength 255
     */
    firstName?: string | null;
    /**
     * Last name.
     * @maxLength 255
     */
    lastName?: string | null;
    /** Form response. */
    formResponse?: FormResponse;
    /** Whether the guest has checked into the event. */
    checkedIn?: boolean;
    /** The login details for the guest to access the online conference event. */
    onlineConferencingLogin?: OnlineConferencingLogin;
    /**
     * Phone extracted from form response. If multiples phone inputs are present, first one is returned.
     * @maxLength 200
     */
    phone?: string | null;
    /**
     * Address extracted from form response. If multiples address inputs are present, first one is returned.
     * @maxLength 200
     */
    address?: string | null;
}
interface FormResponse {
    /**
     * Input values entered when filling the form.
     * @maxSize 200
     */
    inputValues?: InputValue[];
}
interface InputValue {
    /**
     * Input field name.
     * @maxLength 100
     */
    inputName?: string;
    /**
     * Text entered into the input field.
     * @maxLength 5000
     */
    value?: string;
    /**
     * Multiple input values. For example, the array is filled if several checkboxes are ticked.
     * @maxSize 100
     * @maxLength 5000
     */
    values?: string[];
}
declare enum AttendanceStatus {
    /** Not attending. */
    NOT_ATTENDING = "NOT_ATTENDING",
    /** Attending. */
    ATTENDING = "ATTENDING",
    /** In a waiting list. */
    IN_WAITLIST = "IN_WAITLIST"
}
/** @enumType */
type AttendanceStatusWithLiterals = AttendanceStatus | 'NOT_ATTENDING' | 'ATTENDING' | 'IN_WAITLIST';
declare enum GuestType {
    /** An invited guest, no ticket necessary. */
    RSVP = "RSVP",
    /** The guest who bought the ticket. */
    BUYER = "BUYER",
    /** The guest for whom the ticket was bought. */
    TICKET_HOLDER = "TICKET_HOLDER"
}
/** @enumType */
type GuestTypeWithLiterals = GuestType | 'RSVP' | 'BUYER' | 'TICKET_HOLDER';
interface QueryEventGuestsRequest {
    /** Query options. See [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language) for more details. */
    query: QueryV2;
    /**
     * Predefined sets of fields to return.
     * @maxSize 3
     */
    fields?: RequestedFieldsEnumRequestedFieldsWithLiterals[];
}
interface QueryV2 extends QueryV2PagingMethodOneOf {
    /** Paging options to limit and skip the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
    /** Filter object in the following format: <br/> `"filter" : { "fieldName1": "value1", "fieldName2":{"$operator":"value2"} }`. <br/> <br/> **Example:** <br/> `"filter" : { "eventId": "sd3f-jhds-4fs77", "ticketNumber": {"$startsWith":"478"} }` <br/> <br/> See [supported fields and operators](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort) for more information. */
    filter?: Record<string, any> | null;
    /** Sort object in the following format: <br/> `[{"fieldName":"sortField1"},{"fieldName":"sortField2","direction":"DESC"}]` <br/> <br/> **Example:** <br/> `[{"fieldName":"createdDate","direction":"DESC"}]` <br/> <br/> See [supported fields](https://dev.wix.com/api/rest/wix-events/wix-events/filter-and-sort) for more information. */
    sort?: Sorting[];
    /**
     * Currently the only supported fieldset is `guestDetails`. The `WIX_EVENTS.READ_GUESTS_DETAILS` permission is required to access the guest details. <br/> <br/> See [field projection](https://dev.wix.com/api/rest/getting-started/field-projection) for more information.
     * @deprecated Currently the only supported fieldset is `guestDetails`. The `WIX_EVENTS.READ_GUESTS_DETAILS` permission is required to access the guest details. <br/> <br/> See [field projection](https://dev.wix.com/api/rest/getting-started/field-projection) for more information.
     * @replacedBy fields
     * @targetRemovalDate 2024-06-30
     */
    fieldsets?: string[];
}
/** @oneof */
interface QueryV2PagingMethodOneOf {
    /** Paging options to limit and skip the number of items. */
    paging?: Paging;
    /** Cursor token pointing to a page of results. Not used in the first request. Following requests use the cursor token and not `filter` or `sort`. */
    cursorPaging?: CursorPaging;
}
interface Sorting {
    /**
     * Name of the field to sort by.
     * @maxLength 512
     */
    fieldName?: string;
    /** Sort order. */
    order?: SortOrderWithLiterals;
}
declare enum SortOrder {
    ASC = "ASC",
    DESC = "DESC"
}
/** @enumType */
type SortOrderWithLiterals = SortOrder | 'ASC' | 'DESC';
interface Paging {
    /**
     * Number of items to load.
     * @max 1000
     */
    limit?: number | null;
    /** Number of items to skip in the current sort order. */
    offset?: number | null;
}
interface CursorPaging {
    /**
     * Maximum number of items to return in the results.
     * @max 1000
     */
    limit?: number | null;
    /**
     * Pointer to the next or previous page in the list of results.
     *
     * Pass the relevant cursor token from the `pagingMetadata` object in the previous call's response.
     * Not relevant for the first request.
     * @maxLength 16000
     */
    cursor?: string | null;
}
declare enum RequestedFieldsEnumRequestedFields {
    /** Unknown requested field. */
    UNKNOWN_REQUESTED_FIELD = "UNKNOWN_REQUESTED_FIELD",
    /** Returns `guestDetails` and `tickets`. */
    GUEST_DETAILS = "GUEST_DETAILS",
    /** Returns `totalGuests`. */
    GUEST_TOTAL = "GUEST_TOTAL"
}
/** @enumType */
type RequestedFieldsEnumRequestedFieldsWithLiterals = RequestedFieldsEnumRequestedFields | 'UNKNOWN_REQUESTED_FIELD' | 'GUEST_DETAILS' | 'GUEST_TOTAL';
interface QueryEventGuestsResponse {
    /** List of guests. */
    guests?: EventGuest[];
    /** Metadata for the paginated results. */
    pagingMetadata?: PagingMetadataV2;
}
interface PagingMetadataV2 {
    /** Number of items returned in the response. */
    count?: number | null;
    /** Offset that was requested. */
    offset?: number | null;
    /** Total number of items that match the query. Returned if offset paging is used and the `tooManyToCount` flag is not set. */
    total?: number | null;
    /** Flag that indicates the server failed to calculate the `total` field. */
    tooManyToCount?: boolean | null;
    /** Cursors to navigate through the result pages using `next` and `prev`. Returned if cursor paging is used. */
    cursors?: Cursors;
}
interface Cursors {
    /**
     * Cursor string pointing to the next page in the list of results.
     * @maxLength 16000
     */
    next?: string | null;
    /**
     * Cursor pointing to the previous page in the list of results.
     * @maxLength 16000
     */
    prev?: string | null;
}

type __PublicMethodMetaInfo<K = string, M = unknown, T = unknown, S = unknown, Q = unknown, R = unknown> = {
    getUrl: (context: any) => string;
    httpMethod: K;
    path: string;
    pathParams: M;
    __requestType: T;
    __originalRequestType: S;
    __responseType: Q;
    __originalResponseType: R;
};
declare function queryGuests(): __PublicMethodMetaInfo<'POST', {}, QueryEventGuestsRequest$1, QueryEventGuestsRequest, QueryEventGuestsResponse$1, QueryEventGuestsResponse>;

export { type __PublicMethodMetaInfo, queryGuests };
