import { HttpClient, EventDefinition, MaybeContext, BuildRESTFunction, BuildEventDefinition } from '@wix/sdk-types';
import { Q as QueryEventGuestsOptions, G as GuestsQueryBuilder, a as GuestCreatedEnvelope, b as GuestDeletedEnvelope, c as GuestCheckedInEnvelope, d as GuestEventCanceledEnvelope, e as GuestEventStartsEnvelope, f as GuestOrderCanceledEnvelope, g as GuestUpdatedEnvelope } from './events-guests-v1-guest-guests.universal-CBYtnjLy.mjs';
export { at as ActionEvent, x as Address, B as AddressLocation, y as AddressStreetOneOf, A as AttendanceStatus, a$ as BaseEventMetadata, aN as CheckIn, Y as CommonAddress, $ as CommonAddressLocation, Z as CommonAddressStreetOneOf, _ as CommonStreetAddress, a0 as CommonSubdivision, P as ContactEventStatusUpdated, ae as CouponDiscount, aC as CursorPaging, aF as Cursors, a1 as DateAndTimeSettings, ab as Discount, ac as DiscountItem, ad as DiscountItemDiscountOneOf, an as DomainEvent, ao as DomainEventBodyOneOf, aH as Empty, ap as EntityCreatedEvent, as as EntityDeletedEvent, ar as EntityUpdatedEvent, aQ as EventDeleted, V as EventDetails, q as EventGuest, b0 as EventMetadata, E as EventType, aj as Fee, F as FeeName, l as FeeType, v as FormResponse, a4 as Formatted, w as FormattedAddress, U as GuestCheckedIn, aW as GuestCount, J as GuestCountUpdate, H as GuestCountUpdated, u as GuestDetails, ak as GuestEventCanceled, al as GuestEventStarts, aV as GuestListPreview, am as GuestOrderCanceled, h as GuestType, b1 as GuestsQueryResult, av as IdentificationData, aw as IdentificationDataIdOneOf, I as InputValue, a8 as Invoice, a9 as Item, aK as Language, aT as ListGuestListPreviewsRequest, aU as ListGuestListPreviewsResponse, X as Location, L as LocationType, K as MemberEventStatusUpdated, M as MemberEventStatusUpdatedEventType, aY as MemberGuest, aX as MemberGuests, au as MessageEnvelope, aa as Money, N as NotifyActionType, a5 as NotifyGuestAction, a3 as Occurrence, t as OnlineConferencingLogin, aL as OrderConfirmed, aP as OrderDeleted, a7 as OrderDetails, O as OrderStatus, o as OrderType, aO as OrderUpdated, aB as Paging, aE as PagingMetadataV2, af as PaidPlanDiscount, ag as PaidPlanDiscountDiscountOneOf, ah as PercentDiscount, ax as QueryEventGuestsRequest, aD as QueryEventGuestsResponse, ay as QueryV2, az as QueryV2PagingMethodOneOf, R as RecurrenceStatusStatus, a2 as Recurrences, p as RequestedFields, n as RequestedFieldsEnumRequestedFields, aq as RestoreInfo, aI as SecondaryLanguagesRequest, aJ as SecondaryLanguagesResponse, m as SortOrder, aA as Sorting, D as StandardDetails, j as Status, aG as StreamEventGuestsRequest, z as StreetAddress, C as Subdivision, i as SubdivisionSubdivisionType, S as SubdivisionType, aR as Task, a6 as TaskContext, aS as TaskKey, ai as Tax, k as TaxType, aM as Ticket, r as TicketDetails, s as TicketGuestDetails, T as Timing, aZ as UpdateGuestRequest, a_ as UpdateGuestResponse, W as WebhookIdentityType } from './events-guests-v1-guest-guests.universal-CBYtnjLy.mjs';

declare function queryGuests$1(httpClient: HttpClient): QueryGuestsSignature;
interface QueryGuestsSignature {
    /**
     * Creates a query to retrieve a list of guests.
     *
     *
     * The `queryGuests()` method builds a query to retrieve a list of guests and returns a [GuestsQueryBuilder](https://dev.wix.com/docs/sdk/backend-modules/events/guests/guests-query-builder/ascending) object.
     *
     * The returned object contains the query definition which is typically used to run the query using the [`find()`](https://dev.wix.com/docs/sdk/backend-modules/events/guests/guests-query-builder/find) method.
     *
     * You can refine the query by chaining `GuestsQueryBuilder` methods onto the query. `GuestsQueryBuilder` methods enable you to sort, filter, and control the results that `queryGuests.find()` returns.
     *
     * The query runs with the following `GuestsQueryBuilder` defaults that you can override:
     *
     * - [`skipTo(0)`](https://dev.wix.com/docs/sdk/backend-modules/events/guests/guests-query-builder/skip-to)
     * - [`limit(50)`](https://dev.wix.com/docs/sdk/backend-modules/events/guests/guests-query-builder/limit)
     * - [`descending("_createdDate")`](https://dev.wix.com/docs/sdk/backend-modules/events/guests/guests-query-builder/descending)
     *
     * The methods that are chained to `queryGuests()` are applied in the order they are called. For example, if you apply `ascending ('_createdDate')` and then `descending ('_updatedDate')`, the results are sorted first by the created date and then, if there are multiple results with the same date, the items are sorted by the updated date.
     *
     * The table below shows which `GuestsQueryBuilder` methods are supported for `queryGuests()`. You can only use one filter method for each property. Only the first filter will work if a property is used in more than one filter.
     */
    (options?: QueryEventGuestsOptions | undefined): GuestsQueryBuilder;
}
declare const onGuestCreated$1: EventDefinition<GuestCreatedEnvelope, "wix.events.guests.v1.guest_created">;
declare const onGuestDeleted$1: EventDefinition<GuestDeletedEnvelope, "wix.events.guests.v1.guest_deleted">;
declare const onGuestCheckedIn$1: EventDefinition<GuestCheckedInEnvelope, "wix.events.guests.v1.guest_guest_checked_in">;
declare const onGuestEventCanceled$1: EventDefinition<GuestEventCanceledEnvelope, "wix.events.guests.v1.guest_guest_event_canceled">;
declare const onGuestEventStarts$1: EventDefinition<GuestEventStartsEnvelope, "wix.events.guests.v1.guest_guest_event_starts">;
declare const onGuestOrderCanceled$1: EventDefinition<GuestOrderCanceledEnvelope, "wix.events.guests.v1.guest_guest_order_canceled">;
declare const onGuestUpdated$1: EventDefinition<GuestUpdatedEnvelope, "wix.events.guests.v1.guest_updated">;

declare const queryGuests: MaybeContext<BuildRESTFunction<typeof queryGuests$1> & typeof queryGuests$1>;
/**
 * Triggered when a guest is created.
 */
declare const onGuestCreated: BuildEventDefinition<typeof onGuestCreated$1>;
/**
 * Triggered when a guest is deleted.
 */
declare const onGuestDeleted: BuildEventDefinition<typeof onGuestDeleted$1>;
/**
 * Triggered when a guest has checked in.
 */
declare const onGuestCheckedIn: BuildEventDefinition<typeof onGuestCheckedIn$1>;
/**
 * Triggered when an event is canceled.
 */
declare const onGuestEventCanceled: BuildEventDefinition<typeof onGuestEventCanceled$1>;
/**
 * Triggered when an event has started.
 */
declare const onGuestEventStarts: BuildEventDefinition<typeof onGuestEventStarts$1>;
/**
 * Triggered when a ticket order is canceled.
 */
declare const onGuestOrderCanceled: BuildEventDefinition<typeof onGuestOrderCanceled$1>;
/**
 * Triggered when a guest is updated.
 *
 * This event always triggers together with the Guest Created and the Guest Deleted events.
 * > **Note:** Since this event may trigger twice, you should explicitly add code to ensure that the parts of your code that depend on this event run only once.
 */
declare const onGuestUpdated: BuildEventDefinition<typeof onGuestUpdated$1>;

export { GuestCheckedInEnvelope, GuestCreatedEnvelope, GuestDeletedEnvelope, GuestEventCanceledEnvelope, GuestEventStartsEnvelope, GuestOrderCanceledEnvelope, GuestUpdatedEnvelope, GuestsQueryBuilder, QueryEventGuestsOptions, onGuestCheckedIn, onGuestCreated, onGuestDeleted, onGuestEventCanceled, onGuestEventStarts, onGuestOrderCanceled, onGuestUpdated, queryGuests };
